// parameters:
//      dsid: device dsid

dSS.devprops.ShadeCalibrationWizard = Ext.extend(Ext.Window, {
    constructor: function(config) {
        if (config.dsid === undefined) {
           throw dSS._("ShadeCalibrationWizard: missing dSID");
        }

        this.currentStep = 0;

        this.dsid = config.dsid;

        var devStore = dSS.data.Loader.getDeviceStore();
        var record = devStore.getById(this.dsid);
        if (record === undefined) {
            throw dSS._("Device not found");
        }

        var devInfo = dSS.util.parseProductID(record.get('productID'));
        var type = devInfo[0];
        var number = devInfo[1];
        var cls = dSS.util.parseFunctionID(record.get('functionID'));
        var group = cls[0];

        if (group !== dSS.config.groups.SHADOW) {
            throw dSS._("Unsupported device group");
        }

        if (dSS.config.deviceTypes[type] !== "KL") {
            throw dSS._("Unsupported device type");
        }

        var text1 = dSS._("Use the arrow buttons to move the shutter to the " +
                          "upmost position. In case that your shutter was " +
                          "already in the upmost position before calibration " +
                          "was started, you will have to move it a couple of " +
                          "centimeters down and then up, to ensure the " +
                          "correct end position. Please press 'Continue' to " +
                          "automatically lower the shutter.");

        var text2 = dSS._("The shutter is now moving to the lowest " +
                          "position. Various parameters are calculated " +
                          "during that time. Please press 'Continue' as soon " +
                          "as the shutter reaches the lowest position, it " +
                          "will then move up again. The calibration needs " +
                          "to be cancelled and restarted in case that " +
                          "the lowest position was not reached.");

        var text3 = dSS._("The shutter is now moving to the upmost " +
                          "position. Various parameters are calculated " +
                          "during that time. Please klick 'Finish' when the " +
                          "upmost position is reached. The calibration needs " +
                          "to be restarted in case that the upmost position " +
                          "was not reached.");

        if (number === 220) {
            text1 = dSS._("Use the arrow buttons to move the jalousie to the " +
                          "upmost position. In case that your jalousie was " +
                          "already in the upmost position before calibration " +
                          "was started, you will have to move it a couple of " +
                          "centimeters down and then up, to ensure the " +
                          "correct end position. Please press 'Continue' to " +
                          "automatically lower the jalousie.");

            text2 = dSS._("The jalousie is now moving to the lowest " +
                          "position. Various parameters are calculated " +
                          "during that time. Please press 'Continue' as soon " +
                          "as the jalousie reaches the lowest position, it " +
                          "will then move up again. The calibration needs " +
                          "to be cancelled and restarted in case that " +
                          "the lowest position was not reached.");

            text3 = dSS._("The jalousie is now moving to the upmost " +
                          "position. Various parameters are calculated " +
                          "during that time. Please klick 'Finish' when the " +
                          "upmost position is reached. The calibration needs " +
                          "to be restarted in case that the upmost position " +
                          "was not reached.");
        } else if (number === 210) {
            text1 = dSS._("Use the arrow buttons to fully open the marquee. " +
                          "In case that your marquee was " +
                          "already open before calibration " +
                          "was started, you will close it a little bit and " +
                          "then fully open it again, to ensure the " +
                          "correct end position. Please press 'Continue' to " +
                          "automatically close the marquee.");

            text2 = dSS._("The marquee is now closing, various parameters " +
                          "are calculated during that time. Please press " +
                          "'Continue' as soon as the marquee reaches the " +
                          "end position, it will then fully open again. " +
                          "The calibration needs to be cancelled and " +
                          "restarted in case that the end position was not " +
                          "reached.");

            text3 = dSS._("The marquee is now opening. Various parameters " +
                          "are calculated during that time. Please klick " +
                          "'Finish' when the upmost position is reached. " +
                          "The calibration needs to be restarted in case " +
                          "that the marquee was not fully opened.");
        }

        text1 = text1 + '<br/>&nbsp;';

        this.cancelButton = {
            xtype: 'button',
            text: dSS._("Cancel"),
            width: 80,
            scope: this,
            handler: function() {
                this.stopProgmode();
                this.close();
            }
        };

        this.contButton = new Ext.Button({
            text: dSS._("Continue"),
            handler: this.nextStep.createDelegate(this),
            width: 80
        });

        this.delayedTask = new Ext.util.DelayedTask(
            this.delayedCallScene.createDelegate(this),
            this, [ dSS.config.scenes.DEC ]);

        Ext.apply(this, {
            layout: 'card',
            closable: false,
            padding: 10,
            width: 500,
            height: 220,
            resizable: false,
            modal: true,
            title: dSS._("Calibration - step 1 of 3"),
            items:
            [
                {
                    xtype: 'panel',
                    ref: 'step1',
                    layout: 'border',
                    height: 135,
                    border: false,
                    items:
                    [
                        {
                            xtype: 'panel',
                            html: text1,
                            border: false,
                            region: 'north',
                            bodyCfg: {
                                cls: 'x-window-body x-window-mc'
                            }
                        },
                        {
                            xtype: 'panel',
                            region: 'center',
                            ref: 'pos',
                            border: false,
                            bodyCfg: {
                                cls: 'x-window-body x-window-mc'
                            },
                            layout: 'hbox',
                            items:
                            [
                                {
                                    xtype: 'box',
                                    flex: 3
                                },
                                {
                                    xtype: 'button',
                                    iconCls: 'buttonLeftIcon',
                                    ref: 'decButton',
                                    width: 79
                                },
                                {
                                    xtype: 'box',
                                    width: 6
                                },
                                {
                                    xtype: 'button',
                                    iconCls: 'buttonRightIcon',
                                    ref: 'incButton',
                                    width: 79
                                }
                            ]
                        }
                    ]
                },
                {
                    xtype: 'label',
                    html: text2,
                    hidden: true,
                    ref: 'step2'
                },
                {
                    xtype: 'label',
                    html: text3,
                    hidden: true,
                    ref: 'step3'
                }

            ],
            buttons:
            [
                this.contButton,
                this.cancelButton
            ]
        });

        dSS.devprops.ShadeCalibrationWizard.superclass.constructor.apply(this,
                arguments);

        this.on('afterrender', function() {
                this.step1.show();
                this.step2.hide();
                this.step3.hide();
            },
            this);

        this.step1.on('show', function() {
                this.step1.pos.incButton.el.on('mousedown',
                    this.handleIncDown.createDelegate(this),
                    this, { single: true });

                this.step1.pos.decButton.el.on('mousedown',
                    this.handleDecDown.createDelegate(this),
                    this, { single: true });
            },
            this);
    },
    delayedCallScene: function(scene) {
        dSS.util.callScene(this.dsid, scene);
        this.delayedTask.delay(200);
    },
    handleDecDown: function() {
        this.delayedTask.cancel();
        dSS.util.callScene(this.dsid, dSS.config.scenes.DEC);
        this.delayedTask.delay(200,
                this.delayedCallScene.createDelegate(this),
                this, [ dSS.config.scenes.DEC ]);

        this.step1.pos.decButton.el.on('mouseup',
                this.handleDecUp.createDelegate(this),
                this, { single: true });
    },
    handleDecUp: function() {
        this.delayedTask.cancel();
        this.step1.pos.decButton.el.on('mousedown',
                this.handleDecDown.createDelegate(this),
                this, { single: true });

    },
    handleIncDown: function() {
        this.delayedTask.cancel();
        dSS.util.callScene(this.dsid, dSS.config.scenes.INC);
        this.delayedTask.delay(200,
                this.delayedCallScene.createDelegate(this),
                this, [ dSS.config.scenes.INC ]);

        this.step1.pos.incButton.el.on('mouseup',
                this.handleIncUp.createDelegate(this),
                this, { single: true });

    },
    handleIncUp: function() {
        this.delayedTask.cancel();
        this.step1.pos.incButton.el.on('mousedown',
                this.handleIncDown.createDelegate(this),
                this, { single: true });

    },
    nextStep: function() {
        switch (this.currentStep)
        {
            case 0:
                this.currentStep++;
                this.step2.show();
                this.step1.hide();
                this.setTitle(dSS._("Calibration - step 2 of 3"));
                dSS.util.callScene(this.dsid, dSS.config.scenes.MIN);
                break;
            case 1:
                this.currentStep++;
                this.step3.show();
                this.step2.hide();
                this.setTitle(dSS._("Calibration - step 3 of 3"));
                dSS.util.callScene(this.dsid, dSS.config.scenes.MAX);
                this.contButton.setText(dSS._("Finish"));
                break;
            default:
                this.stopProgmode();
                this.close();
                break;
        }
    },
    stopProgmode: function() {
        dSS.util.genericRequest({
                url: '/json/device/setProgMode',
                params: {
                    dsid: this.dsid,
                    mode: 'disable'
                },
                scope: this
            }
        );
    }
});

Ext.reg('dssdevshadecalibrationwizard', dSS.devprops.ShadeCalibrationWizard);

